@@ -339,7 +339,7 @@ class NetworkTestBase(unittest.TestCase):
                                                 stderr=subprocess.PIPE, universal_newlines=True)
                 self.fail('timed out waiting for networkd to settle down:\n%s\n%s\n%s' % (st, st_e, st_e2))
 
-        if subprocess.call(['nm-online', '--quiet', '--timeout=90', '--wait-for-startup']) != 0:
+        if subprocess.call(['nm-online', '--quiet', '--timeout=120', '--wait-for-startup']) != 0:
             self.fail('timed out waiting for NetworkManager to settle down')
 
     def nm_wait_connected(self, iface, timeout):
@@ -374,8 +374,10 @@ class _CommonTests:
   ethernets:
     %(ec)s:
       dhcp4: yes
+      accept-ra: no
     ethbr:
       match: {name: %(e2c)s}
+      accept-ra: no
   bridges:
     mybr:
       interfaces: [ethbr]
@@ -448,6 +450,7 @@ class _CommonTests:
 
     def test_bridge_path_cost(self):
         self.setup_eth(None)
+        self.addCleanup(subprocess.call, ['ip', 'link', 'delete', 'mybr'], stderr=subprocess.DEVNULL)
         self.start_dnsmasq(None, self.dev_e2_ap)
         with open(self.config, 'w') as f:
             f.write('''network:
@@ -455,6 +458,7 @@ class _CommonTests:
   ethernets:
     ethbr:
       match: {name: %(e2c)s}
+      accept-ra: no
   bridges:
     mybr:
       interfaces: [ethbr]
@@ -488,6 +492,7 @@ class _CommonTests:
   ethernets:
     ethbr:
       match: {name: %(e2c)s}
+      accept-ra: no
   bridges:
     mybr:
       interfaces: [ethbr]
@@ -513,6 +518,7 @@ class _CommonTests:
 
     def test_bridge_ageing_time(self):
         self.setup_eth(None)
+        self.addCleanup(subprocess.call, ['ip', 'link', 'delete', 'mybr'], stderr=subprocess.DEVNULL)
         self.start_dnsmasq(None, self.dev_e2_ap)
         with open(self.config, 'w') as f:
             f.write('''network:
@@ -520,6 +526,7 @@ class _CommonTests:
   ethernets:
     ethbr:
       match: {name: %(e2c)s}
+      accept-ra: no
   bridges:
     mybr:
       interfaces: [ethbr]
@@ -545,6 +552,7 @@ class _CommonTests:
 
     def test_bridge_max_age(self):
         self.setup_eth(None)
+        self.addCleanup(subprocess.call, ['ip', 'link', 'delete', 'mybr'], stderr=subprocess.DEVNULL)
         self.start_dnsmasq(None, self.dev_e2_ap)
         with open(self.config, 'w') as f:
             f.write('''network:
@@ -552,6 +560,7 @@ class _CommonTests:
   ethernets:
     ethbr:
       match: {name: %(e2c)s}
+      accept-ra: no
   bridges:
     mybr:
       interfaces: [ethbr]
@@ -577,6 +586,7 @@ class _CommonTests:
 
     def test_bridge_hello_time(self):
         self.setup_eth(None)
+        self.addCleanup(subprocess.call, ['ip', 'link', 'delete', 'mybr'], stderr=subprocess.DEVNULL)
         self.start_dnsmasq(None, self.dev_e2_ap)
         with open(self.config, 'w') as f:
             f.write('''network:
@@ -584,6 +594,7 @@ class _CommonTests:
   ethernets:
     ethbr:
       match: {name: %(e2c)s}
+      accept-ra: no
   bridges:
     mybr:
       interfaces: [ethbr]
@@ -609,6 +620,7 @@ class _CommonTests:
 
     def test_bridge_forward_delay(self):
         self.setup_eth(None)
+        self.addCleanup(subprocess.call, ['ip', 'link', 'delete', 'mybr'], stderr=subprocess.DEVNULL)
         self.start_dnsmasq(None, self.dev_e2_ap)
         with open(self.config, 'w') as f:
             f.write('''network:
@@ -616,6 +628,7 @@ class _CommonTests:
   ethernets:
     ethbr:
       match: {name: %(e2c)s}
+      accept-ra: no
   bridges:
     mybr:
       interfaces: [ethbr]
@@ -641,6 +654,7 @@ class _CommonTests:
 
     def test_bridge_stp_false(self):
         self.setup_eth(None)
+        self.addCleanup(subprocess.call, ['ip', 'link', 'delete', 'mybr'], stderr=subprocess.DEVNULL)
         self.start_dnsmasq(None, self.dev_e2_ap)
         with open(self.config, 'w') as f:
             f.write('''network:
@@ -648,6 +662,7 @@ class _CommonTests:
   ethernets:
     ethbr:
       match: {name: %(e2c)s}
+      accept-ra: no
   bridges:
     mybr:
       interfaces: [ethbr]
@@ -681,6 +696,7 @@ class _CommonTests:
   ethernets:
     ethbn:
       match: {name: %(ec)s}
+      accept-ra: no
     %(e2c)s: {}
   bonds:
     mybond:
@@ -702,8 +718,10 @@ class _CommonTests:
             f.write('''network:
   renderer: %(r)s
   ethernets:
-    %(ec)s: {}
-    %(e2c)s: {}
+    %(ec)s:
+      accept-ra: no
+    %(e2c)s:
+      accept-ra: no
   bonds:
     mybond:
       interfaces: [%(ec)s, %(e2c)s]
@@ -733,7 +751,9 @@ class _CommonTests:
   ethernets:
     ethbn:
       match: {name: %(ec)s}
-    %(e2c)s: {}
+      accept-ra: no
+    %(e2c)s:
+      accept-ra: no
   bonds:
     mybond:
       interfaces: [ethbn]
@@ -760,7 +780,9 @@ class _CommonTests:
   ethernets:
     ethbn:
       match: {name: %(ec)s}
-    %(e2c)s: {}
+      accept-ra: no
+    %(e2c)s:
+      accept-ra: no
   bonds:
     mybond:
       parameters:
@@ -787,7 +809,9 @@ class _CommonTests:
   ethernets:
     ethbn:
       match: {name: %(ec)s}
-    %(e2c)s: {}
+      accept-ra: no
+    %(e2c)s:
+      accept-ra: no
   bonds:
     mybond:
       parameters:
@@ -815,6 +839,7 @@ class _CommonTests:
   ethernets:
     ethbn:
       match: {name: %(ec)s}
+      accept-ra: no
     %(e2c)s: {}
   bonds:
     mybond:
@@ -843,6 +868,7 @@ class _CommonTests:
   ethernets:
     ethbn:
       match: {name: %(ec)s}
+      accept-ra: no
     %(e2c)s: {}
   bonds:
     mybond:
@@ -873,6 +899,7 @@ class _CommonTests:
   ethernets:
     ethbn:
       match: {name: %(ec)s}
+      accept-ra: no
     %(e2c)s: {}
   bonds:
     mybond:
@@ -900,6 +927,7 @@ class _CommonTests:
   ethernets:
     ethbn:
       match: {name: %(ec)s}
+      accept-ra: no
     %(e2c)s: {}
   bonds:
     mybond:
@@ -927,6 +955,7 @@ class _CommonTests:
   ethernets:
     ethbn:
       match: {name: %(ec)s}
+      accept-ra: no
     %(e2c)s: {}
   bonds:
     mybond:
@@ -957,8 +986,10 @@ class _CommonTests:
   ethernets:
     ethbn:
       match: {name: %(ec)s}
+      accept-ra: no
     ethb2:
       match: {name: %(e2c)s}
+      accept-ra: no
   bonds:
     mybond:
       interfaces: [ethbn, ethb2]
@@ -1306,13 +1337,16 @@ wpa_passphrase=12345678
   bonds:
     bond0:
       interfaces: [ethbn, ethb2]
+      accept-ra: no
       parameters:
         mode: balance-rr
   ethernets:
     ethbn:
       match: {name: %(ec)s}
+      accept-ra: no
     ethb2:
       match: {name: %(e2c)s}
+      accept-ra: no
 ''' % {'r': self.backend, 'ec': self.dev_e_client, 'e2c': self.dev_e2_client})
         self.generate_and_settle()
         self.assert_iface_up(self.dev_e_client,
@@ -1348,6 +1382,7 @@ wpa_passphrase=12345678
   bridges:
     br0:
       interfaces: ['bond0', 'vlan2']
+      accept-ra: no
       parameters:
         stp: false
         path-cost:
@@ -1356,20 +1391,25 @@ wpa_passphrase=12345678
   bonds:
     bond0:
       interfaces: ['br1']
+      accept-ra: no
       parameters:
         mode: balance-rr
   bridges:
     br1:
       interfaces: ['ethb2']
+      accept-ra: no
   vlans:
     vlan2:
       link: ethbn
       id: 2
+      accept-ra: no
   ethernets:
     ethbn:
       match: {name: %(ec)s}
+      accept-ra: no
     ethb2:
       match: {name: %(e2c)s}
+      accept-ra: no
 ''' % {'r': self.backend, 'ec': self.dev_e_client, 'e2c': self.dev_e2_client})
         self.generate_and_settle()
         self.assert_iface_up('vlan1', ['vlan1@br0'])
@@ -1385,6 +1425,7 @@ wpa_passphrase=12345678
 class TestNetworkd(NetworkTestBase, _CommonTests):
     backend = 'networkd'
 
+    @unittest.skip("networkd in artful will block waiting for SLAAC")
     def test_eth_dhcp6_off(self):
         self.setup_eth('slaac')
         with open(self.config, 'w') as f:
@@ -1425,6 +1466,7 @@ class TestNetworkd(NetworkTestBase, _CommonTests):
       match:
         name: %(ec)s
         macaddress: %(ec_mac)s
+      accept-ra: no
   bonds:
     mybond:
       interfaces: [ethbn]
@@ -1451,6 +1493,7 @@ class TestNetworkd(NetworkTestBase, _CommonTests):
       match:
         name: %(ec)s
         macaddress: %(ec_mac)s
+      accept-ra: no
   bridges:
     br0:
       interfaces: [ethbr]
@@ -1474,14 +1517,17 @@ class TestNetworkd(NetworkTestBase, _CommonTests):
   ethernets:
     ethbn:
       match: {name: %(ec)s}
-    %(e2c)s: {}
+      accept-ra: no
+    %(e2c)s:
+      accept-ra: no
   bonds:
     mybond:
       interfaces: [ethbn]
       parameters:
         mode: active-backup
-        mii-monitor-interval: 5
-        down-delay: 10
+        mii-monitor-interval: 5s
+        down-delay: 10s
+      accept-ra: no
       dhcp4: yes''' % {'r': self.backend, 'ec': self.dev_e_client, 'e2c': self.dev_e2_client})
         self.generate_and_settle()
         self.assert_iface_up(self.dev_e_client,
@@ -1503,14 +1549,16 @@ class TestNetworkd(NetworkTestBase, _CommonTests):
   ethernets:
     ethbn:
       match: {name: %(ec)s}
+      accept-ra: no
     %(e2c)s: {}
   bonds:
     mybond:
       interfaces: [ethbn]
       parameters:
         mode: active-backup
-        mii-monitor-interval: 5
-        up-delay: 10
+        mii-monitor-interval: 50ms
+        up-delay: 50ms
+      accept-ra: no
       dhcp4: yes''' % {'r': self.backend, 'ec': self.dev_e_client, 'e2c': self.dev_e2_client})
         self.generate_and_settle()
         self.assert_iface_up(self.dev_e_client,
@@ -1521,7 +1569,7 @@ class TestNetworkd(NetworkTestBase, _CommonTests):
         with open('/sys/class/net/mybond/bonding/slaves') as f:
             self.assertEqual(f.read().strip(), self.dev_e_client)
         with open('/sys/class/net/mybond/bonding/updelay') as f:
-            self.assertEqual(f.read().strip(), '10000')
+            self.assertEqual(f.read().strip(), '50')
 
     def test_bond_arp_interval(self):
         self.setup_eth(None)
@@ -1533,6 +1581,7 @@ class TestNetworkd(NetworkTestBase, _CommonTests):
   ethernets:
     ethbn:
       match: {name: %(ec)s}
+      accept-ra: no
     %(e2c)s: {}
   bonds:
     mybond:
@@ -1540,7 +1589,7 @@ class TestNetworkd(NetworkTestBase, _CommonTests):
       parameters:
         mode: balance-xor
         arp-ip-targets: [ 192.168.5.1 ]
-        arp-interval: 50
+        arp-interval: 50s
       dhcp4: yes''' % {'r': self.backend, 'ec': self.dev_e_client, 'e2c': self.dev_e2_client})
         self.generate_and_settle()
         self.assert_iface_up(self.dev_e_client,
@@ -1563,13 +1612,14 @@ class TestNetworkd(NetworkTestBase, _CommonTests):
   ethernets:
     ethbn:
       match: {name: %(ec)s}
+      accept-ra: no
     %(e2c)s: {}
   bonds:
     mybond:
       interfaces: [ethbn]
       parameters:
         mode: balance-xor
-        arp-interval: 50
+        arp-interval: 50s
         arp-ip-targets: [ 192.168.5.1 ]
       dhcp4: yes''' % {'r': self.backend, 'ec': self.dev_e_client, 'e2c': self.dev_e2_client})
         self.generate_and_settle()
@@ -1593,6 +1643,7 @@ class TestNetworkd(NetworkTestBase, _CommonTests):
   ethernets:
     ethbn:
       match: {name: %(ec)s}
+      accept-ra: no
     %(e2c)s: {}
   bonds:
     mybond:
@@ -1600,7 +1651,7 @@ class TestNetworkd(NetworkTestBase, _CommonTests):
       parameters:
         mode: balance-xor
         arp-ip-targets: [192.168.5.1]
-        arp-interval: 50
+        arp-interval: 50s
         arp-all-targets: all
         arp-validate: all
       dhcp4: yes''' % {'r': self.backend, 'ec': self.dev_e_client, 'e2c': self.dev_e2_client})
@@ -1625,6 +1676,7 @@ class TestNetworkd(NetworkTestBase, _CommonTests):
   ethernets:
     ethbn:
       match: {name: %(ec)s}
+      accept-ra: no
     %(e2c)s: {}
   bonds:
     mybond:
@@ -1632,7 +1684,7 @@ class TestNetworkd(NetworkTestBase, _CommonTests):
       parameters:
         mode: balance-xor
         arp-ip-targets: [192.168.5.1]
-        arp-interval: 50
+        arp-interval: 50s
         arp-validate: all
       dhcp4: yes''' % {'r': self.backend, 'ec': self.dev_e_client, 'e2c': self.dev_e2_client})
         self.generate_and_settle()
@@ -1646,6 +1698,41 @@ class TestNetworkd(NetworkTestBase, _CommonTests):
         with open('/sys/class/net/mybond/bonding/arp_validate') as f:
             self.assertEqual(f.read().strip(), 'all 3')
 
+    def test_bridge_port_priority(self):
+        self.setup_eth(None)
+        self.addCleanup(subprocess.call, ['ip', 'link', 'delete', 'mybr'], stderr=subprocess.DEVNULL)
+        self.start_dnsmasq(None, self.dev_e2_ap)
+        with open(self.config, 'w') as f:
+            f.write('''network:
+  renderer: %(r)s
+  ethernets:
+    ethbr:
+      match: {name: %(e2c)s}
+      accept-ra: no
+  bridges:
+    mybr:
+      interfaces: [ethbr]
+      parameters:
+        port-priority:
+          ethbr: 42
+        stp: false
+      dhcp4: yes''' % {'r': self.backend, 'ec': self.dev_e_client, 'e2c': self.dev_e2_client})
+        self.generate_and_settle()
+        self.assert_iface_up(self.dev_e_client,
+                             ['inet 192.168.5.[0-9]+/24'],
+                             ['master'])
+        self.assert_iface_up(self.dev_e2_client,
+                             ['master mybr'],
+                             ['inet '])
+        self.assert_iface_up('mybr',
+                             ['inet 192.168.6.[0-9]+/24'])
+        lines = subprocess.check_output(['bridge', 'link', 'show', 'mybr'],
+                                        universal_newlines=True).splitlines()
+        self.assertEqual(len(lines), 1, lines)
+        self.assertIn(self.dev_e2_client, lines[0])
+        with open('/sys/class/net/mybr/brif/%s/priority' % self.dev_e2_client) as f:
+            self.assertEqual(f.read().strip(), '42')
+
 
 class TestNetworkManager(NetworkTestBase, _CommonTests):
     backend = 'NetworkManager'
@@ -1726,7 +1813,7 @@ class TestNetworkManager(NetworkTestBase, _CommonTests):
       interfaces: [ethbn]
       parameters:
         mode: active-backup
-        mii-monitor-interval: 5
+        mii-monitor-interval: 5000
         down-delay: 10000
       dhcp4: yes''' % {'r': self.backend, 'ec': self.dev_e_client, 'e2c': self.dev_e2_client})
         self.generate_and_settle()
@@ -1755,7 +1842,7 @@ class TestNetworkManager(NetworkTestBase, _CommonTests):
       interfaces: [ethbn]
       parameters:
         mode: active-backup
-        mii-monitor-interval: 5
+        mii-monitor-interval: 5000
         up-delay: 10000
       dhcp4: yes''' % {'r': self.backend, 'ec': self.dev_e_client, 'e2c': self.dev_e2_client})
         self.generate_and_settle()
@@ -1875,7 +1962,7 @@ class TestNetworkManager(NetworkTestBase, _CommonTests):
     mybond:
       parameters:
         mode: balance-tlb
-        mii-monitor-interval: 5
+        mii-monitor-interval: 5000
         learn-packet-interval: 15
       interfaces: [ethbn]
       dhcp4: yes''' % {'r': self.backend, 'ec': self.dev_e_client, 'e2c': self.dev_e2_client})
@@ -1892,5 +1979,39 @@ class TestNetworkManager(NetworkTestBase, _CommonTests):
         with open('/sys/class/net/mybond/bonding/lp_interval') as f:
             self.assertEqual(f.read().strip(), '15')
 
+    def test_bridge_port_priority(self):
+        self.setup_eth(None)
+        self.addCleanup(subprocess.call, ['ip', 'link', 'delete', 'mybr'], stderr=subprocess.DEVNULL)
+        self.start_dnsmasq(None, self.dev_e2_ap)
+        with open(self.config, 'w') as f:
+            f.write('''network:
+  renderer: %(r)s
+  ethernets:
+    ethbr:
+      match: {name: %(e2c)s}
+  bridges:
+    mybr:
+      interfaces: [ethbr]
+      parameters:
+        port-priority:
+          ethbr: 42
+        stp: false
+      dhcp4: yes''' % {'r': self.backend, 'ec': self.dev_e_client, 'e2c': self.dev_e2_client})
+        self.generate_and_settle()
+        self.assert_iface_up(self.dev_e_client,
+                             ['inet 192.168.5.[0-9]+/24'],
+                             ['master'])
+        self.assert_iface_up(self.dev_e2_client,
+                             ['master mybr'],
+                             ['inet '])
+        self.assert_iface_up('mybr',
+                             ['inet 192.168.6.[0-9]+/24'])
+        lines = subprocess.check_output(['bridge', 'link', 'show', 'mybr'],
+                                        universal_newlines=True).splitlines()
+        self.assertEqual(len(lines), 1, lines)
+        self.assertIn(self.dev_e2_client, lines[0])
+        with open('/sys/class/net/mybr/brif/%s/priority' % self.dev_e2_client) as f:
+            self.assertEqual(f.read().strip(), '42')
+
 
 unittest.main(testRunner=unittest.TextTestRunner(stream=sys.stdout, verbosity=2))
